@@ -143,6 +143,22 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            AutoMlClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
@@ -155,7 +171,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            AutoMlClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -321,10 +337,10 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.AutoMlTransport]): The
+            transport (Union[str, AutoMlTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -360,21 +376,17 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                client_cert_source_func = (
+                    mtls.default_client_cert_source() if is_mtls else None
+                )
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -417,7 +429,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -435,16 +447,17 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Creates a dataset.
 
         Args:
-            request (:class:`~.service.CreateDatasetRequest`):
+            request (google.cloud.automl_v1.types.CreateDatasetRequest):
                 The request object. Request message for
                 [AutoMl.CreateDataset][google.cloud.automl.v1.AutoMl.CreateDataset].
-            parent (:class:`str`):
+            parent (str):
                 Required. The resource name of the
                 project to create the dataset for.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            dataset (:class:`~.gca_dataset.Dataset`):
+            dataset (google.cloud.automl_v1.types.Dataset):
                 Required. The dataset to create.
                 This corresponds to the ``dataset`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -457,14 +470,11 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.gca_dataset.Dataset``: A workspace for
-                solving a single, particular machine learning (ML)
-                problem. A workspace contains examples that may be
-                annotated.
+                The result type for the operation will be :class:`google.cloud.automl_v1.types.Dataset` A workspace for solving a single, particular machine learning (ML) problem.
+                   A workspace contains examples that may be annotated.
 
         """
         # Create or coerce a protobuf request object.
@@ -528,12 +538,13 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Gets a dataset.
 
         Args:
-            request (:class:`~.service.GetDatasetRequest`):
+            request (google.cloud.automl_v1.types.GetDatasetRequest):
                 The request object. Request message for
                 [AutoMl.GetDataset][google.cloud.automl.v1.AutoMl.GetDataset].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 dataset to retrieve.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -545,7 +556,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.dataset.Dataset:
+            google.cloud.automl_v1.types.Dataset:
                 A workspace for solving a single,
                 particular machine learning (ML)
                 problem. A workspace contains examples
@@ -603,12 +614,13 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Lists datasets in a project.
 
         Args:
-            request (:class:`~.service.ListDatasetsRequest`):
+            request (google.cloud.automl_v1.types.ListDatasetsRequest):
                 The request object. Request message for
                 [AutoMl.ListDatasets][google.cloud.automl.v1.AutoMl.ListDatasets].
-            parent (:class:`str`):
+            parent (str):
                 Required. The resource name of the
                 project from which to list datasets.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -620,7 +632,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListDatasetsPager:
+            google.cloud.automl_v1.services.auto_ml.pagers.ListDatasetsPager:
                 Response message for
                 [AutoMl.ListDatasets][google.cloud.automl.v1.AutoMl.ListDatasets].
 
@@ -686,18 +698,20 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Updates a dataset.
 
         Args:
-            request (:class:`~.service.UpdateDatasetRequest`):
+            request (google.cloud.automl_v1.types.UpdateDatasetRequest):
                 The request object. Request message for
                 [AutoMl.UpdateDataset][google.cloud.automl.v1.AutoMl.UpdateDataset]
-            dataset (:class:`~.gca_dataset.Dataset`):
+            dataset (google.cloud.automl_v1.types.Dataset):
                 Required. The dataset which replaces
                 the resource on the server.
+
                 This corresponds to the ``dataset`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
                 Required. The update mask applies to
                 the resource.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -709,7 +723,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.gca_dataset.Dataset:
+            google.cloud.automl_v1.types.Dataset:
                 A workspace for solving a single,
                 particular machine learning (ML)
                 problem. A workspace contains examples
@@ -775,12 +789,13 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         [metadata][google.longrunning.Operation.metadata] field.
 
         Args:
-            request (:class:`~.service.DeleteDatasetRequest`):
+            request (google.cloud.automl_v1.types.DeleteDatasetRequest):
                 The request object. Request message for
                 [AutoMl.DeleteDataset][google.cloud.automl.v1.AutoMl.DeleteDataset].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 dataset to delete.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -792,24 +807,22 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
@@ -881,20 +894,22 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
            field when it completes.
 
         Args:
-            request (:class:`~.service.ImportDataRequest`):
+            request (google.cloud.automl_v1.types.ImportDataRequest):
                 The request object. Request message for
                 [AutoMl.ImportData][google.cloud.automl.v1.AutoMl.ImportData].
-            name (:class:`str`):
+            name (str):
                 Required. Dataset name. Dataset must
                 already exist. All imported annotations
                 and examples will be added.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            input_config (:class:`~.io.InputConfig`):
+            input_config (google.cloud.automl_v1.types.InputConfig):
                 Required. The desired input location
                 and its domain specific semantics, if
                 any.
+
                 This corresponds to the ``input_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -906,24 +921,22 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
@@ -991,18 +1004,20 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         completes.
 
         Args:
-            request (:class:`~.service.ExportDataRequest`):
+            request (google.cloud.automl_v1.types.ExportDataRequest):
                 The request object. Request message for
                 [AutoMl.ExportData][google.cloud.automl.v1.AutoMl.ExportData].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 dataset.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            output_config (:class:`~.io.OutputConfig`):
+            output_config (google.cloud.automl_v1.types.OutputConfig):
                 Required. The desired output
                 location.
+
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1014,24 +1029,22 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
@@ -1095,12 +1108,13 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Gets an annotation spec.
 
         Args:
-            request (:class:`~.service.GetAnnotationSpecRequest`):
+            request (google.cloud.automl_v1.types.GetAnnotationSpecRequest):
                 The request object. Request message for
                 [AutoMl.GetAnnotationSpec][google.cloud.automl.v1.AutoMl.GetAnnotationSpec].
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 annotation spec to retrieve.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1112,7 +1126,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.annotation_spec.AnnotationSpec:
+            google.cloud.automl_v1.types.AnnotationSpec:
                 A definition of an annotation spec.
         """
         # Create or coerce a protobuf request object.
@@ -1171,17 +1185,18 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         each annotation spec.
 
         Args:
-            request (:class:`~.service.CreateModelRequest`):
+            request (google.cloud.automl_v1.types.CreateModelRequest):
                 The request object. Request message for
                 [AutoMl.CreateModel][google.cloud.automl.v1.AutoMl.CreateModel].
-            parent (:class:`str`):
+            parent (str):
                 Required. Resource name of the parent
                 project where the model is being
                 created.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            model (:class:`~.gca_model.Model`):
+            model (google.cloud.automl_v1.types.Model):
                 Required. The model to create.
                 This corresponds to the ``model`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1194,12 +1209,12 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.gca_model.Model``: API proto representing a
-                trained machine learning model.
+                :class:`google.cloud.automl_v1.types.Model` API proto
+                representing a trained machine learning model.
 
         """
         # Create or coerce a protobuf request object.
@@ -1263,10 +1278,10 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Gets a model.
 
         Args:
-            request (:class:`~.service.GetModelRequest`):
+            request (google.cloud.automl_v1.types.GetModelRequest):
                 The request object. Request message for
                 [AutoMl.GetModel][google.cloud.automl.v1.AutoMl.GetModel].
-            name (:class:`str`):
+            name (str):
                 Required. Resource name of the model.
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1279,7 +1294,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.model.Model:
+            google.cloud.automl_v1.types.Model:
                 API proto representing a trained
                 machine learning model.
 
@@ -1335,12 +1350,13 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Lists models.
 
         Args:
-            request (:class:`~.service.ListModelsRequest`):
+            request (google.cloud.automl_v1.types.ListModelsRequest):
                 The request object. Request message for
                 [AutoMl.ListModels][google.cloud.automl.v1.AutoMl.ListModels].
-            parent (:class:`str`):
+            parent (str):
                 Required. Resource name of the
                 project, from which to list the models.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1352,7 +1368,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListModelsPager:
+            google.cloud.automl_v1.services.auto_ml.pagers.ListModelsPager:
                 Response message for
                 [AutoMl.ListModels][google.cloud.automl.v1.AutoMl.ListModels].
 
@@ -1420,12 +1436,13 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         [metadata][google.longrunning.Operation.metadata] field.
 
         Args:
-            request (:class:`~.service.DeleteModelRequest`):
+            request (google.cloud.automl_v1.types.DeleteModelRequest):
                 The request object. Request message for
                 [AutoMl.DeleteModel][google.cloud.automl.v1.AutoMl.DeleteModel].
-            name (:class:`str`):
+            name (str):
                 Required. Resource name of the model
                 being deleted.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1437,24 +1454,22 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
@@ -1517,18 +1532,20 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Updates a model.
 
         Args:
-            request (:class:`~.service.UpdateModelRequest`):
+            request (google.cloud.automl_v1.types.UpdateModelRequest):
                 The request object. Request message for
                 [AutoMl.UpdateModel][google.cloud.automl.v1.AutoMl.UpdateModel]
-            model (:class:`~.gca_model.Model`):
+            model (google.cloud.automl_v1.types.Model):
                 Required. The model which replaces
                 the resource on the server.
+
                 This corresponds to the ``model`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
                 Required. The update mask applies to
                 the resource.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1540,7 +1557,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.gca_model.Model:
+            google.cloud.automl_v1.types.Model:
                 API proto representing a trained
                 machine learning model.
 
@@ -1614,12 +1631,13 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         completes.
 
         Args:
-            request (:class:`~.service.DeployModelRequest`):
+            request (google.cloud.automl_v1.types.DeployModelRequest):
                 The request object. Request message for
                 [AutoMl.DeployModel][google.cloud.automl.v1.AutoMl.DeployModel].
-            name (:class:`str`):
+            name (str):
                 Required. Resource name of the model
                 to deploy.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1631,24 +1649,22 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
@@ -1718,12 +1734,13 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         completes.
 
         Args:
-            request (:class:`~.service.UndeployModelRequest`):
+            request (google.cloud.automl_v1.types.UndeployModelRequest):
                 The request object. Request message for
                 [AutoMl.UndeployModel][google.cloud.automl.v1.AutoMl.UndeployModel].
-            name (:class:`str`):
+            name (str):
                 Required. Resource name of the model
                 to undeploy.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1735,24 +1752,22 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
@@ -1822,20 +1837,22 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         completes.
 
         Args:
-            request (:class:`~.service.ExportModelRequest`):
+            request (google.cloud.automl_v1.types.ExportModelRequest):
                 The request object. Request message for
                 [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel].
                 Models need to be enabled for exporting, otherwise an
                 error code will be returned.
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the
                 model to export.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            output_config (:class:`~.io.ModelExportOutputConfig`):
+            output_config (google.cloud.automl_v1.types.ModelExportOutputConfig):
                 Required. The desired output location
                 and configuration.
+
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1847,24 +1864,22 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
@@ -1928,12 +1943,13 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Gets a model evaluation.
 
         Args:
-            request (:class:`~.service.GetModelEvaluationRequest`):
+            request (google.cloud.automl_v1.types.GetModelEvaluationRequest):
                 The request object. Request message for
                 [AutoMl.GetModelEvaluation][google.cloud.automl.v1.AutoMl.GetModelEvaluation].
-            name (:class:`str`):
+            name (str):
                 Required. Resource name for the model
                 evaluation.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1945,7 +1961,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.model_evaluation.ModelEvaluation:
+            google.cloud.automl_v1.types.ModelEvaluation:
                 Evaluation results of a model.
         """
         # Create or coerce a protobuf request object.
@@ -2000,19 +2016,20 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Lists model evaluations.
 
         Args:
-            request (:class:`~.service.ListModelEvaluationsRequest`):
+            request (google.cloud.automl_v1.types.ListModelEvaluationsRequest):
                 The request object. Request message for
                 [AutoMl.ListModelEvaluations][google.cloud.automl.v1.AutoMl.ListModelEvaluations].
-            parent (:class:`str`):
+            parent (str):
                 Required. Resource name of the model
                 to list the model evaluations for. If
                 modelId is set as "-", this will list
                 model evaluations from across all models
                 of the parent location.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            filter (:class:`str`):
+            filter (str):
                 Required. An expression for filtering the results of the
                 request.
 
@@ -2026,6 +2043,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                    4.
                 -  ``NOT annotation_spec_id:*`` --> The model evaluation
                    was done for aggregate of all annotation specs.
+
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -2037,7 +2055,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListModelEvaluationsPager:
+            google.cloud.automl_v1.services.auto_ml.pagers.ListModelEvaluationsPager:
                 Response message for
                 [AutoMl.ListModelEvaluations][google.cloud.automl.v1.AutoMl.ListModelEvaluations].
 
