@@ -34,17 +34,17 @@ class AnnotationPayload(proto.Message):
     r"""Contains annotation information that is relevant to AutoML.
 
     Attributes:
-        translation (~.gca_translation.TranslationAnnotation):
+        translation (google.cloud.automl_v1.types.TranslationAnnotation):
             Annotation details for translation.
-        classification (~.gca_classification.ClassificationAnnotation):
+        classification (google.cloud.automl_v1.types.ClassificationAnnotation):
             Annotation details for content or image
             classification.
-        image_object_detection (~.detection.ImageObjectDetectionAnnotation):
+        image_object_detection (google.cloud.automl_v1.types.ImageObjectDetectionAnnotation):
             Annotation details for image object
             detection.
-        text_extraction (~.gca_text_extraction.TextExtractionAnnotation):
+        text_extraction (google.cloud.automl_v1.types.TextExtractionAnnotation):
             Annotation details for text extraction.
-        text_sentiment (~.gca_text_sentiment.TextSentimentAnnotation):
+        text_sentiment (google.cloud.automl_v1.types.TextSentimentAnnotation):
             Annotation details for text sentiment.
         annotation_spec_id (str):
             Output only . The resource ID of the
