@@ -83,7 +83,7 @@ class DocumentDimensions(proto.Message):
     r"""Message that describes dimension of a document.
 
     Attributes:
-        unit (~.data_items.DocumentDimensions.DocumentDimensionUnit):
+        unit (google.cloud.automl_v1.types.DocumentDimensions.DocumentDimensionUnit):
             Unit of the dimension.
         width (float):
             Width value of the document, works together
@@ -111,15 +111,15 @@ class Document(proto.Message):
     r"""A structured text document e.g. a PDF.
 
     Attributes:
-        input_config (~.io.DocumentInputConfig):
+        input_config (google.cloud.automl_v1.types.DocumentInputConfig):
             An input config specifying the content of the
             document.
-        document_text (~.data_items.TextSnippet):
+        document_text (google.cloud.automl_v1.types.TextSnippet):
             The plain text version of this document.
-        layout (Sequence[~.data_items.Document.Layout]):
+        layout (Sequence[google.cloud.automl_v1.types.Document.Layout]):
             Describes the layout of the document. Sorted by
             [page_number][].
-        document_dimensions (~.data_items.DocumentDimensions):
+        document_dimensions (google.cloud.automl_v1.types.DocumentDimensions):
             The dimensions of the page in the document.
         page_count (int):
             Number of pages in the document.
@@ -131,14 +131,14 @@ class Document(proto.Message):
         in the document.
 
         Attributes:
-            text_segment (~.gca_text_segment.TextSegment):
+            text_segment (google.cloud.automl_v1.types.TextSegment):
                 Text Segment that represents a segment in
                 [document_text][google.cloud.automl.v1p1beta.Document.document_text].
             page_number (int):
                 Page number of the
                 [text_segment][google.cloud.automl.v1.Document.Layout.text_segment]
                 in the original document, starts from 1.
-            bounding_poly (~.geometry.BoundingPoly):
+            bounding_poly (google.cloud.automl_v1.types.BoundingPoly):
                 The position of the
                 [text_segment][google.cloud.automl.v1.Document.Layout.text_segment]
                 in the page. Contains exactly 4
@@ -149,7 +149,7 @@ class Document(proto.Message):
                 [NormalizedVertex-s][google.cloud.automl.v1p1beta.NormalizedVertex]
                 are relative to the page. Coordinates are based on top-left
                 as point (0,0).
-            text_segment_type (~.data_items.Document.Layout.TextSegmentType):
+            text_segment_type (google.cloud.automl_v1.types.Document.Layout.TextSegmentType):
                 The type of the
                 [text_segment][google.cloud.automl.v1.Document.Layout.text_segment]
                 in document.
@@ -201,11 +201,11 @@ class ExamplePayload(proto.Message):
     r"""Example data used for training or prediction.
 
     Attributes:
-        image (~.data_items.Image):
+        image (google.cloud.automl_v1.types.Image):
             Example image.
-        text_snippet (~.data_items.TextSnippet):
+        text_snippet (google.cloud.automl_v1.types.TextSnippet):
             Example text.
-        document (~.data_items.Document):
+        document (google.cloud.automl_v1.types.Document):
             Example document.
     """
 
