@@ -35,7 +35,7 @@ class ImageObjectDetectionAnnotation(proto.Message):
     r"""Annotation details for image object detection.
 
     Attributes:
-        bounding_box (~.geometry.BoundingPoly):
+        bounding_box (google.cloud.automl_v1.types.BoundingPoly):
             Output only. The rectangle representing the
             object location.
         score (float):
@@ -62,7 +62,7 @@ class BoundingBoxMetricsEntry(proto.Message):
         mean_average_precision (float):
             Output only. The mean average precision, most often close to
             au_prc.
-        confidence_metrics_entries (Sequence[~.detection.BoundingBoxMetricsEntry.ConfidenceMetricsEntry]):
+        confidence_metrics_entries (Sequence[google.cloud.automl_v1.types.BoundingBoxMetricsEntry.ConfidenceMetricsEntry]):
             Output only. Metrics for each label-match
             confidence_threshold from
             0.05,0.10,...,0.95,0.96,0.97,0.98,0.99. Precision-recall
@@ -113,7 +113,7 @@ class ImageObjectDetectionEvaluationMetrics(proto.Message):
             Output only. The total number of bounding
             boxes (i.e. summed over all images) the ground
             truth used to create this evaluation had.
-        bounding_box_metrics_entries (Sequence[~.detection.BoundingBoxMetricsEntry]):
+        bounding_box_metrics_entries (Sequence[google.cloud.automl_v1.types.BoundingBoxMetricsEntry]):
             Output only. The bounding boxes match metrics
             for each Intersection-over-union threshold
             0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each
