@@ -78,10 +78,10 @@ class AutoMlTransport(abc.ABC):
             scope (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
@@ -89,6 +89,9 @@ class AutoMlTransport(abc.ABC):
             host += ":443"
         self._host = host
 
+        # Save the scopes.
+        self._scopes = scopes or self.AUTH_SCOPES
+
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
@@ -98,20 +101,17 @@ class AutoMlTransport(abc.ABC):
 
         if credentials_file is not None:
             credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=scopes, quota_project_id=quota_project_id
+                credentials_file, scopes=self._scopes, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
             credentials, _ = auth.default(
-                scopes=scopes, quota_project_id=quota_project_id
+                scopes=self._scopes, quota_project_id=quota_project_id
             )
 
         # Save the credentials.
         self._credentials = credentials
 
-        # Lifted into its own function so it can be stubbed out during tests.
-        self._prep_wrapped_messages(client_info)
-
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -127,6 +127,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -140,6 +141,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -156,6 +158,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -175,6 +178,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -188,6 +192,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -201,6 +206,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -217,6 +223,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -230,6 +237,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -249,6 +257,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -262,6 +271,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -275,6 +285,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
@@ -302,6 +313,7 @@ class AutoMlTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=5.0,
                 ),
                 default_timeout=5.0,
                 client_info=client_info,
