@@ -50,7 +50,7 @@ class BoundingPoly(proto.Message):
     by connecting vertices in the order they are listed.
 
     Attributes:
-        normalized_vertices (Sequence[~.geometry.NormalizedVertex]):
+        normalized_vertices (Sequence[google.cloud.automl_v1beta1.types.NormalizedVertex]):
             Output only . The bounding polygon normalized
             vertices.
     """
